##  Antipatterns
This section addresses antipatterns involving ineffective or counterproductive ways of modeling business context in SAP LeanIX.
  * Don’t mix business context (or subtypes) with business capabilities. Business capabilities define on a more abstract level what your company does to achieve business goals, independent from the organization’s structure, even if there might be overlaps between, e.g., business product and business capabilities regarding the terms used.
  * Don’t mix up your business capabilities (the abilities your business possesses) with other reference capabilities, even if they use the same term (e.g., ESG).
  * If you need to model your business processes in more detail, you should not use SAP LeanIX diagrams but instead a tool like SAP Signavio. SAP LeanIX Diagram is a great feature to model your enterprise architecture and visualize relations on a logical layer, but it is not designed as a comprehensive tool to draw complex business processes.
